@@ -10,8 +10,7 @@ except ImportError:
 try:
     from argparse import ArgumentParser
     from os import isatty, path, getcwd
-    from sys import stdin, stdout, exc_info, executable
-    import subprocess
+    from sys import stdin, stdout, exc_info
     from validators import url
     from traceback import format_exc
     from pathlib import Path
@@ -23,7 +22,7 @@ except ImportError as e:
 
 # ttspod modules
 from ttspod.version import __version__
-from ttspod.util import get_character, get_lock, release_lock
+from ttspod.util import get_character, get_lock, release_lock, upgrade
 
 
 class App(object):
@@ -118,6 +117,8 @@ class App(object):
         self.config_path = args.config
         self.debug = args.debug
         self.quiet = args.quiet
+        if not self.quiet:
+            print(f'TTSPod v{__version__}')
         if self.quiet:
             self.debug = False
         self.log = args.log
@@ -134,7 +135,7 @@ class App(object):
         self.insta = args.insta
         self.url = args.url
         if args.upgrade:
-            subprocess.check_call([executable, "-m", "pip", "install", "ttspod", "-U"])
+            upgrade(force = self.force, debug=self.debug)
             return False
         if not (
             args.url or
@@ -177,8 +178,9 @@ class App(object):
 ttspod_debug=""
 # gpu - set to 0 to disable GPU, otherwise will attempt to use GPU
 # ttspod_gpu="0"
-# log - filename for logging output, leave blank for no logging
-# if not path is specified, logfile would be put under working path
+# log - filename (and optional path) for logging output
+# Leave empty for no logging
+# If no path is specified, logfile is put under ttspod_working_path
 ttspod_log=""
 # path for temporary files (defaults to ./working)
 ttspod_working_path="./working"
