@@ -41,7 +41,7 @@ class Logger(object):
             return
         if self.debug or (error and not self.quiet):
             print(text)
-        text = str(text).replace('\n','\n   ') # indent multiline entries
+        text = str(text).replace('\n', '\n   ')  # indent multiline entries
         if self.log_handle:
             self.log_handle.write(datetime.now().strftime(
                 "%Y-%m-%d %H:%M:%S: ")+str(text)+"\n")
@@ -68,7 +68,7 @@ class Logger(object):
             except Exception as err:  # pylint: disable=broad-except
                 print(f"error opening logfile {self.log_path}: {err}")
         if new_debug and debug:
-            self.write('debug mode is on')
+            self.write('debug mode is now on')
 
     def close(self):
         """close and release log"""
