@@ -7,19 +7,25 @@ except ImportError:
     pass
 
 try:
-    from pypandoc import convert_text
     from html import unescape
     from html2text import html2text
-    from unidecode import unidecode
-    from platform import platform
+    from importlib import reload
+    from importlib.util import find_spec
     from os import path
+    from platform import platform
+    from pypandoc import convert_text
+    from sys import executable
+    from unidecode import unidecode
     import re
+    import subprocess
 except ImportError as e:
     print(
         f'Failed to import required module: {e}\n'
         'Do you need to run pip install -r requirements.txt?')
     exit()
 
+import ttspod.version
+
 OS = None
 my_platform = platform().lower()
 if "windows" in my_platform:
@@ -197,5 +203,66 @@ except ImportError:
         return elements.tile(
             test_elements.shape[0], 1).eq(test_elements.unsqueeze(1)).sum(dim=0).bool().squeeze()
 
+    def upgrade(force=False, debug=False):
+        """upgrade ttspod in place"""
+        current_version = ttspod.version.__version__
+        options = []
+        if find_spec('openai'):
+            options.append('remote')
+        if find_spec('TTS.api'):
+            options.append('local')
+        if find_spec('truststore'):
+            options.append('truststore')
+        if find_spec('twine'):
+            options.append('dev')
+        if options:
+            option_string = re.sub(r"[' ]", '', str(options))
+        else:
+            option_string = ""
+        print(f'Upgrading in place with options {option_string}...')
+        if not force:
+            print(' (include -f to force re-installation) ')
+        results = b''
+        result = subprocess.run(
+            [executable, "-m", "pip", "cache", "remove", "ttspod"],
+            stdout=subprocess.PIPE,
+            stderr=subprocess.PIPE,
+            check=False
+        )
+        results += result.stdout + result.stderr
+        installer = [ executable, "-m", "pip", "install", f"ttspod{option_string}", "-U" ]
+        if force:
+            installer.append("--force-reinstall")
+        result = subprocess.run(
+            installer,
+            stdout=subprocess.PIPE,
+            stderr=subprocess.PIPE,
+            check=False
+        )
+        results += result.stdout + result.stderr
+        if OS == "mac" and 'local' in options:
+            print('Installing customized transformers module for Mac...')
+            result = subprocess.run(
+                [executable, "-m", "pip", "install",
+                 "git+https://github.com/ajkessel/transformers@v4.42.4a", "-U"],
+                stdout=subprocess.PIPE,
+                stderr=subprocess.PIPE,
+                check=False
+            )
+            results += result.stdout + result.stderr
+        results = results.decode('utf-8')
+        lines = [ x for x in results.splitlines() if x.strip() and not "cache is disabled" in x.lower() and ("warning" in x.lower() or "error" in x.lower()) ]
+        if debug:
+            print(results)
+        elif lines:
+            print('Errors/warnings in upgrade:\n')
+            for line in lines:
+                print(f'{line}\n')
+        reload(ttspod.version)
+        new_version = ttspod.version.__version__
+        if current_version != new_version:
+            print(f'Upgraded from {current_version} to {new_version}.')
+        else:
+            print(f'Version unchanged ({current_version}).')
 
 # pylint: enable=c-extension-no-member
